@@ -1,4 +1,5 @@
 from __future__ import annotations
+import copy
 import io
 import typing
 from typing import List, Optional, Callable, Tuple
@@ -7,20 +8,32 @@ from antlr4.Token import CommonToken
 from antlr4.tree.Tree import TerminalNodeImpl
 from antlr4.tree.Tree import ParseTree
 
-
 from thrift_parser import ThriftData
 from thrift_parser.ThriftParser import ThriftParser
 
 
-class PureThriftFormatter(object):
+class Option(object):
     DEFAULT_INDENT: int = 4
 
+    def __init__(self, patch :bool = True, comment :bool = True, indent :Optional[int] = None, assign_align: bool=False):
+        self.patch: bool = patch
+        self.comment: bool = comment
+        self.indent: int = self.DEFAULT_INDENT
+        if indent and indent > 0:
+            self.indent = indent
+        self.assign_align: bool = assign_align
+
+class PureThriftFormatter(object):
+
     def __init__(self):
-        self._option_indent: int = self.DEFAULT_INDENT
+        self._option : Option = Option()
 
         self._newline_c: int = 0
         self._indent_s: str = ''
 
+    def option(self, option: Option):
+        self._option = option
+
     def format_node(self, node: ParseTree):
         self._out: io.StringIO = io.StringIO()
         self._newline_c = 0
@@ -29,10 +42,6 @@ class PureThriftFormatter(object):
         self.process_node(node)
         return self._out.getvalue()
 
-    def set_indent(self, indent: int):
-        if indent > 0:
-            self._option_indent = indent
-
     def _push(self, text: str):
         if self._newline_c > 0:
             self._out.write('\n'*self._newline_c)
@@ -129,27 +138,27 @@ class PureThriftFormatter(object):
         return fn
 
     @staticmethod
-    def gen_subfields_Context(start: int, field_class: typing.Type):
+    def gen_subblocks_Context(start: int, field_class: typing.Type):
         def fn(self: PureThriftFormatter, node: ParseTree):
             self._inline_nodes(node.children[:start])
             self._newline()
-            fields, left = self._get_repeat_children(node.children[start:], field_class)
+            subblocks, left = self._get_repeat_children(node.children[start:], field_class)
 
-            self.before_subfields_hook(fields)
-            self._block_nodes(fields, indent=' ' * self._option_indent)
-            self.after_subfields_hook(fields)
+            self.before_subblocks_hook(subblocks)
+            self._block_nodes(subblocks, indent=' ' * self._option.indent)
+            self.after_subblocks_hook(subblocks)
 
             self._newline()
             self._inline_nodes(left)
         return fn
 
     _gen_inline_Context = gen_inline_Context.__func__
-    _gen_subfields_Context = gen_subfields_Context.__func__
+    _gen_subblocks_Context = gen_subblocks_Context.__func__
 
-    def before_subfields_hook(self, _: List[ParseTree]):
+    def before_subblocks_hook(self, _: List[ParseTree]):
         pass
 
-    def after_subfields_hook(self, _: List[ParseTree]):
+    def after_subblocks_hook(self, _: List[ParseTree]):
         pass
 
     def process_node(self, node: ParseTree):
@@ -205,10 +214,10 @@ class PureThriftFormatter(object):
         tight_fn=lambda i, n: not PureThriftFormatter._is_token(n.parent.children[i-1], ','))
     Const_listContext = _gen_inline_Context(
         tight_fn=lambda _, n: isinstance(n, ThriftParser.List_separatorContext))
-    Enum_ruleContext = _gen_subfields_Context(3, ThriftParser.Enum_fieldContext)
-    Struct_Context = _gen_subfields_Context(3, ThriftParser.FieldContext)
-    Union_Context = _gen_subfields_Context(3, ThriftParser.FieldContext)
-    Exception_Context = _gen_subfields_Context(3, ThriftParser.FieldContext)
+    Enum_ruleContext = _gen_subblocks_Context(3, ThriftParser.Enum_fieldContext)
+    Struct_Context = _gen_subblocks_Context(3, ThriftParser.FieldContext)
+    Union_Context = _gen_subblocks_Context(3, ThriftParser.FieldContext)
+    Exception_Context = _gen_subblocks_Context(3, ThriftParser.FieldContext)
     Enum_fieldContext = _gen_inline_Context(
         join=' ',
         tight_fn=lambda _, n: isinstance(n, ThriftParser.List_separatorContext))
@@ -236,9 +245,9 @@ class PureThriftFormatter(object):
     Annotation_valueContext = _gen_inline_Context()
 
     def ServiceContext(self, node: ThriftParser.ServiceContext):
-        fn = self.gen_subfields_Context(3, ThriftParser.Function_Context)
+        fn = self.gen_subblocks_Context(3, ThriftParser.Function_Context)
         if self._is_token(node.children[2], 'extends'):
-            fn = self.gen_subfields_Context(5, ThriftParser.Function_Context)
+            fn = self.gen_subblocks_Context(5, ThriftParser.Function_Context)
         return fn(self, node)
 
     def SenumContext(self, node: ThriftParser.SenumContext):
@@ -253,22 +262,12 @@ class ThriftFormatter(PureThriftFormatter):
         self._data: ThriftData = data
         self._document: ThriftParser.DocumentContext = data.document
 
-        self._option_comment: bool = True
-        self._option_patch: bool = True
-
-        self._field_padding: int = 0
+        self._field_assign_padding: int = 0
+        self._field_comment_padding: int = 0
         self._last_token_index: int = -1
 
-    def option(self, comment: Optional[bool] = None, patch: Optional[bool] = None, indent: Optional[int] = None):
-        if comment is not None:
-            self._option_comment = comment
-        if patch is not None:
-            self._option_patch = patch
-        if indent is not None:
-            self.set_indent(indent)
-
     def format(self) -> str:
-        if self._option_patch:
+        if self._option.patch:
             self.patch()
 
         return self.format_node(self._document)
@@ -349,28 +348,95 @@ class ThriftFormatter(PureThriftFormatter):
         if is_last and isinstance(node.children[-1], ThriftParser.List_separatorContext):
             node.children.pop()
 
-    def _calc_subfields_padding(self, fields: List[ParseTree]):
-        if not fields:
-            return 0
+    @staticmethod
+    def _is_field_or_enum_field(node: ParseTree):
+        return isinstance(node, (ThriftParser.FieldContext, ThriftParser.Enum_fieldContext))
 
-        padding = 0
-        for field in fields:
-            out = PureThriftFormatter().format_node(field)
-            if len(out) > padding:
-                padding = len(out)
-        return padding
+    @staticmethod
+    def _split_field_define_assign(node: ParseTree):
+        '''
+          split field to [left, right]
+          field: '1: required i32 number_a = 0,'
+          left:  '1: required i32 number_a'
+          right: '= 0,'
+        '''
+        assert ThriftFormatter._is_field_or_enum_field(node)
+        left = copy.copy(node)
+        right = copy.copy(node)
 
-    def before_subfields_hook(self, fields: List[ParseTree]):
-        self._field_padding = self._calc_subfields_padding(fields) + self._option_indent
+        i = 0
+        for i, child in enumerate(node.children):
+            if ThriftFormatter._is_token(child, '='):
+                break
 
-    def after_subfields_hook(self, _: List[ParseTree]):
-        self._field_padding = 0
+        left.children = node.children[:i]
+        right.children = node.children[i:]
+        return left, right
+
+    def _calc_subblocks_padding(self, subblocks: List[ParseTree]) -> Tuple[int, int]:
+        if not subblocks:
+            return 0, 0
+
+        # only field is FieldContext or Enum_fieldContext
+        if self._option.assign_align and self._is_field_or_enum_field(subblocks[0]):
+            '''
+                field: '1: required i32 number_a = 0,'
+                assign_padding:    field.index('=')
+                comment_padding:  max(assign) + max(left)
+            '''
+            left_max_size = 0
+            right_max_size = 0
+            for field in subblocks:
+                left, right = self._split_field_define_assign(field)
+                left_size = len(PureThriftFormatter().format_node(left))
+                right_size = len(PureThriftFormatter().format_node(right))
+
+                left_max_size = max(left_max_size, left_size)
+                right_max_size = max(right_max_size, right_size)
+
+            # add extra space
+            assign_padding = left_max_size + 1
+            comment_padding = left_max_size + 1 + right_max_size
+        else:
+            assign_padding = 0
+            comment_padding = 0
+            for subblock in subblocks:
+                subblock_size = len(PureThriftFormatter().format_node(subblock))
+                comment_padding = max(comment_padding, subblock_size)
+
+        return assign_padding, comment_padding
+
+    def before_subblocks_hook(self, subblocks: List[ParseTree]):
+        # subblocks : [ Function ] | [ Field]
+
+        # calculate the subblocks's padding
+        assign_padding, comment_padding = self._calc_subblocks_padding(subblocks)
+        if assign_padding > 0:
+            self._field_assign_padding = assign_padding + self._option.indent
+        if comment_padding > 0:
+            self._field_comment_padding = comment_padding + self._option.indent
+
+    def after_subblocks_hook(self, _: List[ParseTree]):
+        self._field_assign_padding = 0
+        self._field_comment_padding = 0
 
     def after_block_node_hook(self, _: ParseTree):
         self._tail_comment()
 
+    def _get_current_line(self):
+        cur = self._out.getvalue().rsplit('\n', 1)[-1]
+        return cur
+
+    def _padding(self, padding: int, pad: str=' '):
+        if padding <= 0:
+            return
+        cur = self._get_current_line()
+        padding = padding - len(cur)
+        if padding > 0:
+            self._append(pad * padding)
+
     def _line_comments(self, node: TerminalNodeImpl):
-        if not self._option_comment:
+        if not self._option.comment:
             return
 
         if hasattr(node.symbol, 'is_fake') and node.symbol.is_fake:
@@ -403,7 +469,7 @@ class ThriftFormatter(PureThriftFormatter):
         self._last_token_index = node.symbol.tokenIndex
 
     def _tail_comment(self):
-        if not self._option_comment:
+        if not self._option.comment:
             return
 
         if self._last_token_index == -1:
@@ -420,12 +486,7 @@ class ThriftFormatter(PureThriftFormatter):
 
         assert len(comments) <= 1
         if comments:
-            if self._field_padding > 0:
-                cur = len(self._out.getvalue().rsplit('\n', 1)[-1])
-                padding = self._field_padding - cur
-                if padding > 0:
-                    self._append(' ' * padding)
-
+            self._padding(self._field_comment_padding, ' ')
             self._append(' ')
             self._append(comments[0].text.strip())
             self._push('')
@@ -441,4 +502,8 @@ class ThriftFormatter(PureThriftFormatter):
         # add abrove comments
         self._line_comments(node)
 
+        # add field assign padding
+        if self._option.assign_align and self._is_field_or_enum_field(node.parent) and self._is_token(node, '='):
+            self._padding(self._field_assign_padding, ' ')
+
         super().TerminalNodeImpl(node)
