@@ -1,9 +1,9 @@
 import click
 import io
 import pathlib
+from typing import Optional
 
-
-from .core import ThriftData, ThriftFormatter
+from .core import ThriftData, ThriftFormatter, Option
 
 
 @click.command()
@@ -14,16 +14,17 @@ from .core import ThriftData, ThriftFormatter
     help='Write to file instead of stdout, default true when dir was set')
 @click.option(
     '-i', '--indent', type=click.IntRange(min=0), default=None,
-    help='struct/enum/service sub fields indent, default {}'.format(
-        ThriftFormatter.DEFAULT_INDENT))
+    help='sub field indent of struct/enum/service/union/exception, default {}'.format(Option.DEFAULT_INDENT))
 @click.option(
-    '--no-patch', is_flag=True, help='not patch thrift file')
+    '--no-patch', is_flag=True, help='disable field patch about comma and required flag')
 @click.option(
     '--remove-comment', is_flag=True, help='remove all comment')
+@click.option(
+    '--no-assign-align', is_flag=True, help='disable field assign align')
 @click.argument(
     'file',
     type=click.Path(exists=True, file_okay=True, dir_okay=False), required=False)
-def main(dir, write, indent, no_patch, remove_comment, file):
+def main(dir, write: Optional[bool], indent: Optional[int], no_patch: Optional[bool], remove_comment: Optional[bool], no_assign_align: Optional[bool], file):
     if not dir and not file:
         raise click.ClickException('thrift file or dir is required')
 
@@ -33,13 +34,16 @@ def main(dir, write, indent, no_patch, remove_comment, file):
         files = pathlib.Path(dir).glob('*.thrift')
         write = True
 
-    patch = not no_patch
-    comment = not remove_comment
+    option = Option(
+        patch=not no_patch,
+        comment=not remove_comment,
+        indent=indent,
+        assign_align=not no_assign_align)
 
     for file in files:
         data = ThriftData.from_file(file)
         fmt = ThriftFormatter(data)
-        fmt.option(comment=comment, patch=patch, indent=indent)
+        fmt.option(option)
         output = fmt.format()
 
         if write:
